/*
*   This is an example of how to have a TDecoratedFrame with both 
*  wfShrinkToFit set and the WS_THICKFRAME turned off. In OWL 2.5, there 
*  is currently a bug that will not allow you to do both of these things 
*  before you create the frame. The workaround used below is to set the 
*  wfShrinkToFit flag for the TDecoratedFrame, but leave the WS_THICKFRAME 
*  style on until after the window and it's children (client windows) and 
*  siblings (control bars, status bars, etc.) are created. Then use 
*  SetWindowLong to get rid of the WS_THICKFRAME style.
*
*  JGD 6/27/95
*
*/



#include <owl\applicat.h>
#include <owl\dialog.h>
#include <owl\decframe.h>
#include <owl\dc.h>
#include <owl\statusba.h>
#include <owl\controlb.h>
#include <iostream.h>
#include "dlgmain.rh"

const int WM_CHANGEFRAMESTYLE = WM_USER + 0x100;

class TMyDialog : public TDialog
{
   public:
      TMyDialog(TWindow* parent, int id) : TDialog(parent, id)
      {}

      void SetupWindow();

      LRESULT CmChangeFrameStyle(WPARAM,LPARAM);

   DECLARE_RESPONSE_TABLE( TMyDialog );
};

DEFINE_RESPONSE_TABLE1( TMyDialog, TDialog )
   EV_MESSAGE( WM_CHANGEFRAMESTYLE, CmChangeFrameStyle),
END_RESPONSE_TABLE;

void TMyDialog::SetupWindow()
{
   TDialog::SetupWindow();

   // All the children and siblings of the frame have been created. 
   // Post a message to call a function to change the style.
   PostMessage( WM_CHANGEFRAMESTYLE, 0, 0 );
}

LRESULT TMyDialog::CmChangeFrameStyle(WPARAM /*wParam*/, LPARAM /*lParam*/ )
{
    long style;
    TFrameWindow* frame = GetApplication()->GetMainWindow();
    style = frame->GetWindowLong( GWL_STYLE );

    style &= ~(WS_THICKFRAME);
    frame->SetWindowLong( GWL_STYLE, style );

    // Redraw the frame.
    frame->SetWindowPos( 0, 0, 0, 0, 0,
                         SWP_NOZORDER | SWP_NOMOVE |
                         SWP_NOSIZE | SWP_DRAWFRAME );
    return 0;
}

////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////

class TMyApp : public TApplication
{
     private:
     public:
         TMyApp();

         void InitMainWindow();
};

TMyApp::TMyApp() : TApplication()
{

}


void TMyApp::InitMainWindow()
{
    TDecoratedFrame* frame = new TDecoratedFrame( NULL, "Dialog as Main Window",
                                                  new TMyDialog(NULL, DIALOG_1) );

    TStatusBar* sb = new TStatusBar( 0, TGadget::Recessed,
                                     TStatusBar::CapsLock |
                                     TStatusBar::NumLock |
                                     TStatusBar::Overtype );

    TControlBar* cb = new TControlBar( frame );
    cb->Insert( *new TSeparatorGadget( 10 ) );


    frame->SetFlag( wfShrinkToClient );


    frame->Insert( *sb, TDecoratedFrame::Bottom );
    frame->Insert( *cb, TDecoratedFrame::Top );


    SetMainWindow(frame);
}

/////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////

int OwlMain(int, char**)
{
    return TMyApp().Run();
}



